% Kristen Stewart
% u1067886

% Initialize given parameters
Tn = 50;           
Ts = 30;
Tw = 50;
Te = 100;
tSides = [Tn Tw Te Ts];     % temp along each side: measured in degrees F
n = 5;                     % grid size

% Generate A and b for system using provided function
[A, b] = HeatedPlateMesh(n, tSides);

% Find vector solution to A*x = b since A is square invertible matrix
x = (A^-1)*b;
 
% Rearrange solution x into a matrix of temperatures at each node
Tgrid = TempMatrix(x, tSides, n);
xGrid = [0:n+1]/(n+1);
yGrid = [0:n+1]'/(n+1);

% Generate contour plot
contourf(xGrid, yGrid, Tgrid, 15); colorbar('vert');


%% Increase number of nodes from 5 to 20
figure
n1 = 20;                     % grid size

% Generate A and b for system using provided function
[A1, b1] = HeatedPlateMesh(n1, tSides);

% Find vector solution to A*x = b since A is square invertible matrix
x1 = (A1^-1)*b1;
 
% Rearrange solution x into a matrix of temperatures at each node
Tgrid1 = TempMatrix(x1, tSides, n1);
xGrid1 = [0:n1+1]/(n1+1);
yGrid1 = [0:n1+1]'/(n1+1);

% Generate contour plot
contourf(xGrid1, yGrid1, Tgrid1, 15); colorbar('vert');


%% Change boundary conditions from prescribed temperatures to one side with convection
h = 10;
deltaX = 0.2;
k = 1;
convCoeff = h*deltaX/k;
T_inf = 30;
A2 = A;
b2 = b;
% Node 1- Account for convection
A2(1,1) = A2(1,1) + 2*convCoeff;
A2(1,6) = -2;
b2(1) = 50 + 2*convCoeff*T_inf;
% Node 2 - Account for convection
A2(2,2) = A2(2,2) + 2*convCoeff;
A2(2, 7) = -2; 
b2(2) = 2*convCoeff*T_inf;
% Node 3 - Account for convection
A2(3,3) = A2(3,3) + 2*convCoeff;
A2(3,8) = -2;
b2(3) = 2*convCoeff*T_inf;
% Node 4 - Account for convection
A2(4,4) = A2(4,4) + 2*convCoeff;
A2(4,9) = -2;
b2(4) = 2*convCoeff*T_inf;
% Node 5 - Account for convection
A2(5,5) = A2(5,5) + 2*convCoeff;
A2(5,10) = -2;
b2(5) = 100 + 2*convCoeff*T_inf;

% Find vector solution to A*x = b since A is square invertible matrix
x2 = (A2^-1)*b2;
 
% Rearrange solution x into a matrix of temperatures at each node
Tgrid2 = TempMatrix(x2, tSides, n);
xGrid2 = [0:n+1]/(n+1);
yGrid2 = [0:n]'/(n);
Tgrid3(1:6, 1:7) = Tgrid2(2:7, 1:end);
Tgrid3(1,1) = NaN;
Tgrid3(1,end) = NaN;
% Generate contour plot
figure
contourf(xGrid2, yGrid2, Tgrid3, 15); colorbar('vert');

%% Change boundary condition from prescribed temperature to insulated surface
A3 = A;
b3 = b;
% Node 1 - account for insulation
A3(1,6) = -2;
b3(1) = 50;
% Node 2 - account for insulation
A3(2,7) = -2;
b3(2) = 0;
% Node 3 - account for insulation
A3(3, 8) = -2;
b3(3) = 0;
% Node 4 - account for insulation
A3(4,9) = -2;
b3(4) = 0;
% Node 5 - account for insulation
A3(5,10) = -2;
b3(5) = 100;


% Find vector solution to A*x = b since A is square invertible matrix
x3 = (A3^-1)*b3;
 
% Rearrange solution x into a matrix of temperatures at each node
Tgrid = TempMatrix(x3, tSides, n);
xGrid = [0:n+1]/(n+1);
yGrid = [0:n+1]'/(n+1);
Tgrid(1,1:end) = Tgrid(2,1:end);    % insulated, so no prescribed temperature or heat transfer along surface

% Generate contour plot
figure
contourf(xGrid, yGrid, Tgrid, 15); colorbar('vert');



